/*
 * Copyright (C) 2022-2025 Seagull Developers
 *
 * Seagull is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(SEAGULL_GLOBAL_HEADER_INSIDE) && !defined(SEAGULL_COMPILATION)
# error "only <seagull.h> may be included directly"
#endif

#ifndef SEAGULL_MEMORY_H
#define SEAGULL_MEMORY_H

#include <glib.h>
#include <gio/gio.h>

#include "seagullversion.h"

G_BEGIN_DECLS

/**
 * seagull_free:
 * @value: the value to free
 *
 * Frees memory allocated by SQLite3.
 *
 * This is a wrapper around `sqlite3_free`. It is provided for completeness and
 * to avoid having to link to SQLite3 directly.
 *
 * Since: 0.3
 */
SEAGULL_AVAILABLE_IN_0_3
void seagull_free(gpointer value);

G_END_DECLS

#endif /* SEAGULL_MEMORY_H */
